@@ -305,7 +305,7 @@ There is no default.
 
 =end pod
 
-class Audio::Libshout:ver<v0.0.6>:auth<github:jonathanstowe> {
+class Audio::Libshout:ver<v0.0.7>:auth<github:jonathanstowe> {
     use NativeCall;
     use AccessorFacade;
 
@@ -362,19 +362,19 @@ class Audio::Libshout:ver<v0.0.6>:auth<github:jonathanstowe> {
     }
 
     class Metadata is repr('CPointer') {
-        sub shout_metadata_new() returns Metadata is native('libshout') { * }
+        sub shout_metadata_new() returns Metadata is native('shout',v3) { * }
 
         method new() {
             shout_metadata_new();
         }
 
-        sub shout_metadata_free(Metadata) is native('libshout') { * }
+        sub shout_metadata_free(Metadata) is native('shout',v3) { * }
 
         method DESTROY() {
             shout_metadata_free(self);
         }
 
-        sub shout_metadata_add(Metadata, Str, Str ) returns int32 is native('libshout') { * }
+        sub shout_metadata_add(Metadata, Str, Str ) returns int32 is native('shout',v3) { * }
 
         method add(Str $key is rw, Str $value is rw) returns Error {
             explicitly-manage($key);
@@ -387,7 +387,7 @@ class Audio::Libshout:ver<v0.0.6>:auth<github:jonathanstowe> {
 
     class Shout is repr('CPointer') {
 
-        sub shout_new() returns Shout is native('libshout') { * }
+        sub shout_new() returns Shout is native('shout',v3) { * }
 
         method new(Shout:U: *%attribs) returns Shout {
             my $shout = shout_new();
@@ -400,27 +400,27 @@ class Audio::Libshout:ver<v0.0.6>:auth<github:jonathanstowe> {
             $shout;
         }
 
-        sub shout_free(Shout) returns int32 is native('libshout') { * }
+        sub shout_free(Shout) returns int32 is native('shout',v3) { * }
 
         submethod DESTROY() {
             shout_free(self);
         }
 
-        sub shout_open(Shout) returns int32 is native('libshout') { * }
+        sub shout_open(Shout) returns int32 is native('shout',v3) { * }
 
         method open() returns Error {
             my $rc = shout_open(self);
             Error($rc);
         }
 
-        sub shout_close(Shout) returns int32 is native('libshout') { * }
+        sub shout_close(Shout) returns int32 is native('shout',v3) { * }
 
         method close() returns Error {
             my $rc = shout_close(self);
             Error($rc);
         }
         
-        sub shout_send(Shout, CArray[uint8], int32) returns int32 is native('libshout') { * }
+        sub shout_send(Shout, CArray[uint8], int32) returns int32 is native('shout',v3) { * }
 
         multi method send(CArray[uint8] $buf, Int $elems) returns Error {
             my $rc = shout_send(self, $buf, $elems);
@@ -433,7 +433,7 @@ class Audio::Libshout:ver<v0.0.6>:auth<github:jonathanstowe> {
             self.send($carray, $buf.elems);
         }
 
-        sub shout_sync(Shout) is native('libshout') { * }
+        sub shout_sync(Shout) is native('shout',v3) { * }
 
         method sync() {
             shout_sync(self);
@@ -457,97 +457,97 @@ class Audio::Libshout:ver<v0.0.6>:auth<github:jonathanstowe> {
 
         # "attributes"
         #
-        sub shout_set_host(Shout, Str) returns int32 is native('libshout') { * }
-        sub shout_get_host(Shout) returns Str is native('libshout') { * }
+        sub shout_set_host(Shout, Str) returns int32 is native('shout',v3) { * }
+        sub shout_get_host(Shout) returns Str is native('shout',v3) { * }
 
         method host() returns Str is rw is accessor-facade(&shout_get_host, &shout_set_host, &manage, &check) { }
 
-        sub shout_set_port(Shout, int32) returns int32 is native('libshout') { * }
-        sub shout_get_port(Shout) returns int32 is native('libshout') { * }
+        sub shout_set_port(Shout, int32) returns int32 is native('shout',v3) { * }
+        sub shout_get_port(Shout) returns int32 is native('shout',v3) { * }
 
         method port() returns Int is rw is accessor-facade(&shout_get_port, &shout_set_port, Code, &check) { }
 
-        sub shout_set_user(Shout, Str) returns int32 is native('libshout') { * }
-        sub shout_get_user(Shout) returns Str is native('libshout') { * }
+        sub shout_set_user(Shout, Str) returns int32 is native('shout',v3) { * }
+        sub shout_get_user(Shout) returns Str is native('shout',v3) { * }
 
         method user() returns Str is rw is accessor-facade(&shout_get_user, &shout_set_user, &manage, &check) { }
 
-        sub shout_set_password(Shout, Str) returns int32 is native('libshout') { * }
-        sub shout_get_password(Shout) returns Str is native('libshout') { * }
+        sub shout_set_password(Shout, Str) returns int32 is native('shout',v3) { * }
+        sub shout_get_password(Shout) returns Str is native('shout',v3) { * }
 
         method password() returns Str is rw is accessor-facade(&shout_get_password, &shout_set_password, &manage, &check) { }
 
-        sub shout_get_protocol(Shout) returns int32 is native('libshout') { * }
-        sub shout_set_protocol(Shout, int32) returns int32 is native('libshout') { * }
+        sub shout_get_protocol(Shout) returns int32 is native('shout',v3) { * }
+        sub shout_set_protocol(Shout, int32) returns int32 is native('shout',v3) { * }
 
         method protocol() returns Protocol is rw is accessor-facade(&shout_get_protocol, &shout_set_protocol, Code, &check) { }
 
-        sub shout_get_format(Shout) returns int32 is native('libshout') { * }
-        sub shout_set_format(Shout, int32) returns int32 is native('libshout') { * }
+        sub shout_get_format(Shout) returns int32 is native('shout',v3) { * }
+        sub shout_set_format(Shout, int32) returns int32 is native('shout',v3) { * }
 
         method format() returns Format is rw is accessor-facade(&shout_get_format, &shout_set_format, Code, &check) { }
 
-        sub shout_get_mount(Shout) returns Str is native('libshout') { * }
-        sub shout_set_mount(Shout, Str) returns int32 is native('libshout') { * }
+        sub shout_get_mount(Shout) returns Str is native('shout',v3) { * }
+        sub shout_set_mount(Shout, Str) returns int32 is native('shout',v3) { * }
 
         method mount() returns Str is rw is accessor-facade(&shout_get_mount, &shout_set_mount, &manage, &check) { }
 
-        sub shout_get_dumpfile(Shout) returns Str is native('libshout') { * }
-        sub shout_set_dumpfile(Shout, Str ) returns int32 is native('libshout') { * }
+        sub shout_get_dumpfile(Shout) returns Str is native('shout',v3) { * }
+        sub shout_set_dumpfile(Shout, Str ) returns int32 is native('shout',v3) { * }
 
         method dumpfile() returns Str is rw is accessor-facade(&shout_get_dumpfile, &shout_set_dumpfile, &manage, &check ) { }
 
-        sub shout_get_agent(Shout) returns Str is native('libshout') { * }
-        sub shout_set_agent(Shout, Str) returns int32 is native('libshout') { * }
+        sub shout_get_agent(Shout) returns Str is native('shout',v3) { * }
+        sub shout_set_agent(Shout, Str) returns int32 is native('shout',v3) { * }
 
         method agent() returns Str is rw is accessor-facade(&shout_get_agent, &shout_set_agent, &manage, &check) { }
 
         # Directory parameters
-        sub shout_get_public(Shout) returns int32 is native('libshout') { * }
-        sub shout_set_public(Shout, int32) returns int32 is native('libshout') { * }
+        sub shout_get_public(Shout) returns int32 is native('shout',v3) { * }
+        sub shout_set_public(Shout, int32) returns int32 is native('shout',v3) { * }
 
         method public returns Bool is rw is accessor-facade(&shout_get_public, &shout_set_public, Code, &check) { }
 
-        sub shout_get_name(Shout) returns Str is native('libshout') { * }
-        sub shout_set_name(Shout, Str) returns int32 is native('libshout') { * }
+        sub shout_get_name(Shout) returns Str is native('shout',v3) { * }
+        sub shout_set_name(Shout, Str) returns int32 is native('shout',v3) { * }
 
         method name() returns Str is rw is accessor-facade(&shout_get_name, &shout_set_name, &manage, &check) { }
 
-        sub shout_get_url(Shout) returns Str is native('libshout') { * }
-        sub shout_set_url(Shout, Str) returns int32 is native('libshout') { * }
+        sub shout_get_url(Shout) returns Str is native('shout',v3) { * }
+        sub shout_set_url(Shout, Str) returns int32 is native('shout',v3) { * }
 
         method url() returns Str is rw is accessor-facade(&shout_get_url, &shout_set_url, &manage, &check) { }
 
-        sub shout_get_genre(Shout) returns Str is native('libshout') { * }
-        sub shout_set_genre(Shout, Str) returns int32 is native('libshout') { * }
+        sub shout_get_genre(Shout) returns Str is native('shout',v3) { * }
+        sub shout_set_genre(Shout, Str) returns int32 is native('shout',v3) { * }
 
         method genre() returns Str is rw is accessor-facade(&shout_get_genre, &shout_set_genre, &manage, &check) { }
 
-        sub shout_get_description(Shout) returns Str is native('libshout') { * }
-        sub shout_set_description(Shout, Str) returns int32 is native('libshout') { * }
+        sub shout_get_description(Shout) returns Str is native('shout',v3) { * }
+        sub shout_set_description(Shout, Str) returns int32 is native('shout',v3) { * }
 
         method description() returns Str is rw is accessor-facade(&shout_get_description, &shout_set_description, &manage, &check) { }
 
         # Not making a method for these quite yet.
-        sub shout_get_audio_info(Shout, Str) returns Str is native('libshout') { * }
-        sub shout_set_audio_info(Shout, Str, Str) returns Str is native('libshout') { * }
+        sub shout_get_audio_info(Shout, Str) returns Str is native('shout',v3) { * }
+        sub shout_set_audio_info(Shout, Str, Str) returns Str is native('shout',v3) { * }
 
         # Set the metadata on this instance.
 
-        sub shout_set_metadata(Shout, Metadata) returns int32 is native('libshout') { * }
+        sub shout_set_metadata(Shout, Metadata) returns int32 is native('shout',v3) { * }
 
         method set-metadata(Metadata $meta) returns Error {
             my $rc = shout_set_metadata(self, $meta);
             Error($rc);
         }
 
-        sub shout_get_error(Shout) returns Str is native('libshout') { * };
+        sub shout_get_error(Shout) returns Str is native('shout',v3) { * };
 
         method last-error() returns Str {
             shout_get_error(self);
         }
 
-        sub shout_get_errno(Shout) returns int32 is native('libshout') { * };
+        sub shout_get_errno(Shout) returns int32 is native('shout',v3) { * };
 
         method last-error-number() returns Error {
             my $rc = shout_get_errno(self);
@@ -558,7 +558,7 @@ class Audio::Libshout:ver<v0.0.6>:auth<github:jonathanstowe> {
     class Initialiser {
         has Int $!initialisers = 0;
 
-        sub shout_init() is native('libshout') { * }
+        sub shout_init() is native('shout',v3) { * }
 
         method init() {
             if $!initialisers == 0 {
@@ -567,7 +567,7 @@ class Audio::Libshout:ver<v0.0.6>:auth<github:jonathanstowe> {
             ++$!initialisers;
         }
 
-        sub shout_shutdown() is native('libshout') { * }
+        sub shout_shutdown() is native('shout',v3) { * }
 
         method shutdown() {
             --$!initialisers;
@@ -680,7 +680,7 @@ class Audio::Libshout:ver<v0.0.6>:auth<github:jonathanstowe> {
     }
 
 
-    sub shout_version(int32, int32, int32) returns Str is native('libshout') { * }
+    sub shout_version(int32, int32, int32) returns Str is native('shout',v3) { * }
     method libshout-version() returns Version {
         my int32 $major;
         my int32 $minor;
